@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 import sys
 import os
+import re
 
 
 if len(sys.argv) > 1 and sys.argv[1] in ['light', '--light']:
@@ -77,6 +78,8 @@ def arg_parse():
     dev_group.add_argument("-lint", "--linter", action="store_true", help="Run micrOS system linter (pylint+)")
     dev_group.add_argument("-webrepl", "--open_webrepl", action="store_true", help="(beta) Open webrepl in default browser, micropython repl + file transfers (built-in)")
     dev_group.add_argument("--light", action="store_true", help="Skip optional dependency deployments (low level param: add this as first argument always)")
+    dev_group.add_argument("-ut", "--unittest", action="store_true", help="Run micrOS unit tests - for development")
+
 
     toolkit_group = parser.add_argument_group("Toolkit development")
     toolkit_group.add_argument("--dummy", action="store_true", help="Skip subshell executions - for API logic test.")
@@ -113,7 +116,13 @@ def install(api_obj):
 
 def connect(args=None):
     if args is not None and len(args) != 0:
-        arg_list = args.split()
+        # REPARSE IINPUT DUE TO EMBEDDED INPUT PARSER... HACK
+        # extract quoted content (without quotes)
+        extracted = re.findall(r'(["\'])(.*?)\1', args)
+        extracted = [text for _, text in extracted]
+        # remove quoted parts from original string
+        cleaned = re.sub(r'(["\']).*?\1', '', args)
+        arg_list = cleaned.split() + extracted
         socketClient.run(arg_list=arg_list)
     else:
         socketClient.run(arg_list=[])
@@ -216,6 +225,13 @@ def update_pip_package():
     return True if out == 0 else False
 
 
+def run_unit_tests():
+    """Run micrOS Unit tests under micrOS/utests/*"""
+    import unittest
+    suite = unittest.defaultTestLoader.discover("micrOS/utests")
+    unittest.TextTestRunner(verbosity=2).run(suite)
+
+
 if __name__ == "__main__":
     # Arg parse
     cmd_args = arg_parse()
@@ -310,4 +326,7 @@ if __name__ == "__main__":
             executor = macroScript.Executor()
             executor.run_micro_script(cmd_args.macro)
 
+    if cmd_args.unittest:
+        run_unit_tests()
+
     sys.exit(0)
