@@ -16,11 +16,13 @@ from re import search
 from json import load, dump
 from uos import remove
 from utime import sleep
-from Debug import DebugCfg, console_write, errlog_add
+from Debug import DebugCfg, console_write, syslog
+from Files import OSPath, path_join, is_file
+from uos import rename as move_file
 try:
     from microIO import set_pinmap
 except:
-    errlog_add("[ERR] LogicalPins import: set_pinmap")
+    syslog("[ERR] microIO import: set_pinmap")
     set_pinmap = None
 
 
@@ -30,7 +32,8 @@ class Data:
     """
     __slots__ = []
 
-    CONFIG_PATH = "node_config.json"
+    CONFIG_NAME = "node_config.json"
+    CONFIG_PATH = path_join(OSPath.CONFIG, CONFIG_NAME)
     CONFIG_CACHE = {"version": "n/a",
                     "auth": False,
                     "staessid": "your_wifi_name",
@@ -68,17 +71,23 @@ class Data:
                     "boostmd": True,
                     "guimeta": "...",       # special "offloaded" key indicator
                     "cstmpmap": "n/a",
-                    "telegram": "n/a",      # telegram bot token
                     "espnow": False}
 
     @staticmethod
     def init():
+        # Migrate config from / to /config
+        if is_file(Data.CONFIG_NAME):
+            console_write(f"[CONF] Migrate {Data.CONFIG_NAME} to {Data.CONFIG_PATH}")
+            move_file(Data.CONFIG_NAME, Data.CONFIG_PATH)
         # Inject user config into template
         Data.__inject_default_conf()
         # [!!!] Init selected pinmap - default pinmap calculated by platform
-        if set_pinmap is not None:
-            pinmap = set_pinmap(Data.CONFIG_CACHE['cstmpmap'])
-            console_write(f"[PIN MAP] {pinmap}")
+        if callable(set_pinmap):
+            try:
+                pinmap = set_pinmap(Data.CONFIG_CACHE['cstmpmap'])
+                console_write(f"[PIN MAP] {pinmap}")
+            except Exception as e:
+                console_write(f"\n[PIN MAP] !!! SETUP ERROR !!!: {e}\n")
         # SET dbg based on config settings (inject user conf)
         DebugCfg.DEBUG = Data.CONFIG_CACHE['dbg']
         if DebugCfg.DEBUG:
@@ -95,12 +104,12 @@ class Data:
         liveconf = Data.read_cfg_file(nosafe=True)
         # Remove obsolete keys from conf
         try:
-            remove('cleanup.pds')       # Try to remove cleanup.pds (cleanup indicator by micrOSloader)
+            remove('.cleanup')       # Try to remove .cleanup (cleanup indicator by micrOSloader)
             console_write("[CONF] Purge obsolete keys")
             for key in (key for key in liveconf if key not in Data.CONFIG_CACHE):
                 liveconf.pop(key, None)
         except Exception:
-            console_write("[CONF] SKIP obsolete keys check (no cleanup.pds)")
+            console_write("[CONF] SKIP obsolete keys check (no .cleanup)")
         # Merge template to live conf (store active conf in Data.CONFIG_CACHE)
         Data.CONFIG_CACHE.update(liveconf)
         console_write("[CONF] User config injection done")
@@ -109,7 +118,7 @@ class Data:
             Data.write_cfg_file()
             console_write("[CONF] Save conf successful")
         except Exception as e:
-            errlog_add(f"[ERR] Save (__inject) conf failed: {e}")
+            syslog(f"[ERR] Save (__inject) conf failed: {e}")
         finally:
             del liveconf
 
@@ -127,7 +136,7 @@ class Data:
                 if nosafe:
                     break
                 sleep(0.2)
-                errlog_add(f'[ERR] read_cfg_file error: {e}')
+                syslog(f'[ERR] read_cfg_file error: {e}')
         # Return config cache
         return conf
 
@@ -140,7 +149,7 @@ class Data:
                     dump(Data.CONFIG_CACHE, f)
                 break
             except Exception as e:
-                errlog_add(f'[ERR] write_cfg_file {Data.CONFIG_PATH} (json): {e}')
+                syslog(f'[ERR] write_cfg_file {Data.CONFIG_PATH} (json): {e}')
             sleep(0.2)
         return True
 
@@ -171,16 +180,17 @@ class Data:
         These kind of parameters are not cached in memory
         """
         # Write str value to file
+        offloaded_key = path_join(OSPath.CONFIG, f'.{key}.key')
         if isinstance(value, str) and key in Data.CONFIG_CACHE:
             try:
-                with open(f'.{key}.key', 'w') as f:
+                with open(offloaded_key, 'w') as f:
                     f.write(value)
                 return True
             except Exception:
                 return False
         # Read str value from file
         try:
-            with open(f'.{key}.key', 'r') as f:
+            with open(offloaded_key, 'r') as f:
                 return f.read().strip()
         except Exception:
             # Return default value if key not exists
@@ -217,7 +227,7 @@ def cfgget(key=None):
             return Data.disk_keys(key)
         return val
     except Exception as e:
-        errlog_add(f'[ERR] cfgget {key} error: {e}')
+        syslog(f'[ERR] cfgget {key} error: {e}')
     return None
 
 def cfgput(key, value, type_check=False):
@@ -242,7 +252,7 @@ def cfgput(key, value, type_check=False):
         del value
         return True
     except Exception as e:
-        errlog_add(f'[ERR] cfgput {key} error: {e}')
+        syslog(f'[ERR] cfgput {key} error: {e}')
         return False
 
 #################################################################
