@@ -19,10 +19,9 @@ Designed by Marcell Ban aka BxNxM
 #################################################################
 from Config import cfgget, cfgput
 from microIO import detect_platform
-from Debug import console_write, errlog_add
+from Debug import console_write, syslog
 from Tasks import exec_lm_pipe
-from Files import OSPath, is_dir
-from uos import mkdir
+from Auth import resolve_secret
 from micropython import mem_info
 from machine import freq
 try:
@@ -45,11 +44,10 @@ def bootup():
     """
     # Execute LMs from boothook config parameter
     console_write("[BOOT] EXECUTION...")
-    _init_micros_dirs()
     bootasks = cfgget('boothook')
     if bootasks is not None and bootasks.lower() != 'n/a':
         console_write(f"|-[BOOT] TASKS: {bootasks}")
-        if exec_lm_pipe(bootasks):
+        if exec_lm_pipe(resolve_secret(bootasks)):
             console_write("|-[BOOT] DONE")
         else:
             console_write("|-[BOOT] ERROR")
@@ -62,25 +60,6 @@ def bootup():
     _tune_performance()
 
 
-def _init_micros_dirs():
-    """
-    Init micrOS root file system directories
-    """
-    root_dirs = [
-        getattr(OSPath, key)
-        for key in dir(OSPath)
-        if not key.startswith("_") and isinstance(getattr(OSPath, key), str)
-    ]
-    console_write(f"|-[BOOT] rootFS validation: {root_dirs}")
-    for dir_path in root_dirs:
-        if not is_dir(dir_path):
-            try:
-                mkdir(dir_path)
-                errlog_add(f"[BOOT] init dir: {dir_path}")
-            except Exception as e:
-                errlog_add(f"[ERR][BOOT] cannot init dir {dir_path}: {e}")
-
-
 def _tune_queue_size():
     """
     Tune queue size based on available ram
@@ -96,20 +75,26 @@ def _tune_queue_size():
 
 
 def _tune_performance():
-    # Set boosted (boost mode)
+    # {(platforms, ...): (min_clock, max_clock), ...}
+    cpu_clocks = {
+        ('esp32c3', 'esp32c6'): (80_000_000, 160_000_000),
+        ('esp32',): (160_000_000, 240_000_000),  # default
+    }
     platform = detect_platform()
-    if cfgget('boostmd') is True:
-        console_write(f"[BOOT HOOKS] Set up CPU high Hz - boostmd: {cfgget('boostmd')}")
-        if platform == 'esp32c3':
-            freq(160_000_000)   # 160 Mhz (max)
-        elif 'esp32' in platform:
-            freq(240_000_000)   # 240 Mhz (max)
+    cpu_min_max = cpu_clocks[('esp32',)]
+    for platforms, clocks in cpu_clocks.items():
+        if platform in platforms:
+            cpu_min_max = clocks
+            break
+    # Set boosted (boost mode)
+    if cfgget('boostmd'):
+        max_hz = cpu_min_max[1]
+        console_write(f"[BOOT HOOKS] CPU boost mode ON: {max_hz} Hz")
+        freq(max_hz)
     else:
-        console_write(f"[BOOT HOOKS] Set up CPU low Hz - boostmd: {cfgget('boostmd')}")
-        if platform == 'esp32c3':
-            freq(80_000_000)   # 80 Mhz / Half the max CPU clock
-        elif 'esp32' in platform:
-            freq(160_000_000)   # 160 Mhz / Half the max CPU clock
+        min_hz = cpu_min_max[0]
+        console_write(f"[BOOT HOOKS] CPU boost mode OFF: {min_hz} Hz")
+        freq(min_hz)
 
 
 def profiling_info(label=""):
@@ -137,7 +122,7 @@ def boot_cause():
             reason = 4, "DSWakeUp"
         elif reset_reason == SOFT_RESET:
             reason = 5, "SoftReset"
-    errlog_add(f"[BOOT] info: {reason[1]}")
+    syslog(f"[BOOT] info: {reason[1]}")
     return reason
 
 
@@ -151,6 +136,6 @@ def enableESPNow() -> str:
             verdict = ESPNowSS().start_server()
             console_write(f"[TASK] Start ESPNow-InterCon server: {verdict}")
         except Exception as e:
-            errlog_add(f"[ERR] Start ESPNow-InterCon server: {e}")
+            syslog(f"[ERR] Start ESPNow-InterCon server: {e}")
             return str(e)
     return "ESPNow disabled"
