@@ -1,14 +1,35 @@
+"""
+Module is responsible for device-device communication
+dedicated to micrOS framework.
+Built-in-function:
+- Socket InterConnect interface
+- ESPNow redirection
+
+Designed by 
+    Marcell Ban aka BxNxM
+    Kristof Kasza aka KKristof452
+"""
+
 from socket import getaddrinfo, SOCK_STREAM
-from re import compile
+from re import compile as re_compile
+from json import loads
+from binascii import hexlify
 from uasyncio import open_connection
-from Debug import errlog_add
+
+from Debug import syslog
 from Config import cfgget
 from Server import Server
 from Tasks import NativeTask
 
+if cfgget('espnow'):
+    from Espnow import ESPNowSS
+else:
+    ESPNowSS = None
+
 
 class InterCon:
-    CONN_MAP = {}
+    CONN_MAP: dict[str, str] = {}   # hostname: IP address pairs
+    NO_ESPNOW: list[str] = []       # disabled ESPNow hostname list (cache for fallback speed-up)
     PORT = cfgget('socport')
 
     def __init__(self):
@@ -19,7 +40,7 @@ class InterCon:
 
     @staticmethod
     def validate_ipv4(str_in):
-        pattern = compile(r'^(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])$')
+        pattern = re_compile(r'^(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])$')
         return bool(pattern.match(str_in))
 
     async def send_cmd(self, host:str, cmd:list):
@@ -34,14 +55,19 @@ class InterCon:
         # Check if host is a hostname (example.local) and resolve its IP address
         if not InterCon.validate_ipv4(host):
             hostname = host
-            # Retrieve IP address by hostname dynamically
+            # Lookup hostname without .domain (sub-hostname matching)
+            if '.' not in hostname:
+                _hosts = list([d for d in InterCon.CONN_MAP if hostname in d])
+                if len(_hosts) > 0:
+                    hostname = _hosts[0]
+            # Retrieve IP address by hostname.domain dynamically
             if InterCon.CONN_MAP.get(hostname, None) is None:
                 try:
                     addr_info = getaddrinfo(host, InterCon.PORT, 0, SOCK_STREAM)
                     host = addr_info[-1][4][0]
                 except OSError as e:
                     Server.reply_all(f"[intercon] NoHost: {e}")
-                    errlog_add(f"[intercon] send_cmd {host} oserr: {e}")
+                    syslog(f"[intercon] send_cmd {host} oserr: {e}")
                     return ''
             else:
                 # Restore IP from cache by hostname
@@ -55,7 +81,7 @@ class InterCon:
                 output = await self.__run_command(cmd, hostname)
             except OSError as e:
                 Server.reply_all(f"[intercon] NoHost: {e}")
-                errlog_add(f"[intercon] send_cmd {host} oserr: {e}")
+                syslog(f"[intercon] send_cmd {host} oserr: {e}")
                 output = None
             finally:
                 if self.writer:
@@ -68,8 +94,7 @@ class InterCon:
                 InterCon.CONN_MAP[hostname] = None if output is None else host
             # None: ServerBusy(or \0) or Prompt mismatch (auto delete cached IP), STR: valid comm. output
             return output
-        else:
-            errlog_add(f"[ERR][intercon] Invalid host: {host}")
+        syslog(f"[ERR][intercon] Invalid host: {host}")
         return ''
 
     async def __run_command(self, cmd:list, hostname:str):
@@ -85,7 +110,6 @@ class InterCon:
         # Compare prompt |node01 $| with hostname 'node01.local'
         if hostname is None or prompt is None or str(prompt).replace('$', '').strip() == str(hostname).split('.')[0]:
             # Run command on validated device
-            # TODO: Handle multiple cmd as input, separated by ; (????)
             self.writer.write(str.encode(' '.join(cmd)))
             await self.writer.drain()
             data, _ = await self.__receive_data(prompt=prompt)
@@ -103,13 +127,13 @@ class InterCon:
             await self.writer.drain()
             data, prompt = await self.__receive_data(prompt=prompt)
         except Exception as e:
-            errlog_add(f'[intercon][ERR] Auth: {e}')
+            syslog(f'[intercon][ERR] Auth: {e}')
             data = 'AuthFailed'
         if 'AuthOk' in data:
             return True             # AuthOk
         return False                # AuthFailed
 
-    async def __receive_data(self, prompt=None):
+    async def __receive_data(self, prompt=None) -> tuple[str, str]:
         """
         Implements data receive loop until prompt / [configure] / Bye!
         :param prompt: socket shell prompt
@@ -139,8 +163,34 @@ class InterCon:
         data = data.replace(prompt, '').replace('\n', ' ')
         return data, prompt
 
+    async def auto_espnow_handshake(self, host:str) -> dict:
+        """
+        [1] Check espnow.server running on host
+        [2] Get MAC address for host (from system info)
+        [3] Execute ESPNowSS.handshake
+        """
+        response = await self.send_cmd(host, ["task", "list", ">json"])
+        if not response:
+            return {None: f"[ERR] ESPNow auto handshake: task list >>{host}: {response}"}
 
-async def _send_cmd(host:str, cmd:list, com_obj):
+        active_tasks = loads(response).get("active")
+        if active_tasks and "espnow.server" in active_tasks:
+            response = await self.send_cmd(host, ["system", "info", ">json"])
+            if not response:
+                return {None: "[ERR] ESPNow auto handshake: system info"}
+            try:
+                host_mac = loads(response).get("mac")
+            except Exception as ex:
+                return {None: f"[ERR] ESPNow auto handshake: {ex}"}
+
+            return ESPNowSS().handshake(host_mac)
+
+        if not InterCon.validate_ipv4(host):
+            InterCon.NO_ESPNOW.append(str(host).split(".")[0])   # host.local -> host
+        return {None: f"ESPNow auto handshake: espnow disabled on host {host}"}
+
+
+async def _socket_send_cmd(host:str, cmd:list, com_obj:InterCon) -> None:
     """
     Async send command wrapper for further async task integration and sync send_cmd usage (main)
     :param host: hostname / IP address
@@ -148,46 +198,77 @@ async def _send_cmd(host:str, cmd:list, com_obj):
     :param com_obj: InterCon object to utilize send_cmd method and task status updates
     """
     # Send command
+    for _ in range(0, 2):                           # Retry mechanism
+        out = await com_obj.send_cmd(host, cmd)     # Send CMD
+        if out is not None:                         # Retry mechanism
+            break
+        await com_obj.task.feed(sleep_ms=100)       # Retry mechanism
+    com_obj.task.out = '' if out is None else out
+
+
+async def _send_cmd(host:str, cmd:list|str, com_obj:InterCon):
+    """
+    Top level InterConnect callback function
+        [1] node01.domain -> ESPNow, Socket
+                (domain: .local, .net, etc.)
+        [2] node01 -> ESPNow, Socket fallback in case found in InterConnect cache
+        [3] IP address -> Socket
+    """
     with com_obj.task:
-        for _ in range(0, 4):                           # Retry mechanism
-            out = await com_obj.send_cmd(host, cmd)     # Send CMD
-            if out is not None:                         # Retry mechanism
-                break
-            await com_obj.task.feed(sleep_ms=100)       # Retry mechanism
-        com_obj.task.out = '' if out is None else out
-    return com_obj.task.out
+        if ESPNowSS:
+            # [1] ESPNow Active
+            name = str(host).split(".")[0]   # host.local -> host
+            if name not in InterCon.NO_ESPNOW and name in list(ESPNowSS().devices.values()):
+                com_obj.task.out = "Redirected to ESPNow"
+                if isinstance(cmd, list):
+                    cmd = ' '.join(cmd)
+                # Send command and retrieve result
+                sender = ESPNowSS().send(peer=name, msg=cmd)
+                sender_task = NativeTask.TASKS.get(list(sender.keys())[0])
+                result = await sender_task.await_result(timeout=10)
+                if result != "Timeout has beed exceeded":
+                    # Successful command execution
+                    com_obj.task.out = result                       # Output mirroring: Child -> Parent
+                    sender_task.out = "Redirected to ParentTask"    # Remove redundant data in embedded mode
+                    return
+
+        # Handle legacy string input
+        if isinstance(cmd, str):
+            cmd = cmd.split()
+        # [1][2] Socket send (default and fallback)
+        await _socket_send_cmd(host, cmd, com_obj)
+
+        if ESPNowSS and name not in InterCon.NO_ESPNOW:
+            # [3] Automatic ESPNow handshake
+            verdict = await com_obj.auto_espnow_handshake(host)
+            if list(verdict.keys())[0] is None:
+                syslog(str(list(verdict.values())[0]))
 
 
 def send_cmd(host:str, cmd:list|str) -> dict:
     """
-    Sync wrapper of async _send_cmd (InterCon.send_cmd consumer with retry)
-    :param host: hostname / IP address
-    :param cmd: command string to server socket shell
+    Top level InterConnect send task creation
+        Handles ESPNow and socket communication
     """
     def _tagify():
         nonlocal host, cmd
         _mod = cmd[0]
         if InterCon.validate_ipv4(host):
             return f"{'.'.join(host.split('.')[-2:])}.{_mod}"
-        return f"{host.replace('.local', '')}.{_mod}"
-
-    # Handle legacy string input
-    if isinstance(cmd, str):
-        cmd = cmd.split()
+        target = ".".join(host.split(".")[0:-1]) if "." in host else host
+        return f"{target}.{_mod}"
 
     com_obj = InterCon()
-    tag = f"con.{_tagify()}"
-    started = com_obj.task.create(callback=_send_cmd(host, cmd, com_obj), tag=tag)
-    if started:
-        result = {"verdict": f"Task started: task show {tag}", "tag": tag}
-    else:
-        result = {"verdict": "Task is Busy", "tag": tag}
-    return result
+    task_id = f"con.{_tagify()}"            # CHECK TASK ID CONFLICT
+    return com_obj.task.create(callback=_send_cmd(host, cmd, com_obj), tag=task_id)
 
 
 def host_cache() -> dict:
     """
     Dump InterCon connection cache
     """
-    return InterCon.CONN_MAP
-
+    if ESPNowSS is None:
+        return InterCon.CONN_MAP
+    all_devs = dict({name:hexlify(mac, ':').decode() for mac, name in ESPNowSS().devices.items()})
+    all_devs.update(InterCon.CONN_MAP)
+    return all_devs
