@@ -13,7 +13,7 @@ Designed by Marcell Ban aka BxNxM GitHub
 import uasyncio as asyncio
 from utime import ticks_ms, ticks_diff
 from Config import cfgget
-from Debug import console_write, errlog_add
+from Debug import console_write, syslog
 from Network import ifconfig
 from Tasks import Manager
 from Shell import Shell
@@ -27,11 +27,20 @@ except:
 if cfgget('webui'):
     from Web import WebEngine
 else:
-    # Create dummy web engine - Laizy loading
+    # Create dummy web engine - Lazy loading
     class WebEngine:
         __slots__ = []
         def __init__(self, *args, **kwargs):
             pass
+        @staticmethod
+        def register(*args, **kwargs) -> None:
+            """Child class can implement"""
+            syslog(f"[WARN] webui disabled, skip register: {kwargs.get('endpoint')}")
+        @staticmethod
+        def web_mounts(*args, **kwargs) -> dict:
+            """Child class can implement"""
+            syslog(f"[WARN] webui disabled, skip web_mounts: {kwargs.get('endpoint')}")
+            return {}
 
 #########################################################
 #         SOCKET SERVER-CLIENT HANDLER CLASSES          #
@@ -63,19 +72,25 @@ class Client:
         console_write("|" + "-" * Client.INDENT + msg)
         Client.INDENT += 1 if Client.INDENT < 50 else 0       # Auto indent
 
-    async def read(self):
+    async def read(self, decoding='utf8', timeout_seconds=0):
         """
         [Base] Implements client read function, reader size: 2048
-        - set timeout counter
-        - read input from client (run: return False)
-        - connection error handling (stop: return True)
-        - exit command handling (stop: return True)
+        :return tuple: read_error, data
+        - read_error is set to true upon timeout or other exception
+        - data holds bytes or decoded string read from the socket
         """
         Client.console(f"[Client] read {self.client_id}")
         self.last_msg_t = ticks_ms()
         try:
-            request = await self.reader.read(self.read_bytes)
-            request = request.decode('utf8').strip()
+            if timeout_seconds:
+                request = await asyncio.wait_for(self.reader.read(self.read_bytes), timeout_seconds)
+            else:
+                request = await self.reader.read(self.read_bytes)
+            if decoding:
+                request = request.decode(decoding)
+        except asyncio.TimeoutError:
+            Client.console(f"[Client] Stream read timeout ({self.client_id}), timeout={timeout_seconds}s")
+            return True, ''
         except Exception as e:
             Client.console(f"[Client] Stream read error ({self.client_id}): {e}")
             collect()           # gc collection: "fix" for memory allocation failed, allocating 2049 bytes
@@ -83,8 +98,6 @@ class Client:
 
         # Input handling
         Client.console(f"[Client] raw request ({self.client_id}): |{request}|")
-        if request in ('exit', ''):
-            return True, request
         return False, request
 
     async def a_send(self, response, encode='utf8'):
@@ -99,7 +112,7 @@ class Client:
             except Exception as e:
                 # Maintain ACTIVE_CLIS - remove closed connection by peer.
                 await self.close()
-                errlog_add(f"[WARN] Client.a_send (auto-drop) {self.client_id}: {e}")
+                syslog(f"[WARN] Client.a_send (auto-drop) {self.client_id}: {e}")
                 return          # Abort async send (no drain)
             # Send buffered data with async task - hacky
             try:
@@ -142,7 +155,7 @@ class Client:
         if Client.ACTIVE_CLIS.get(client_id, None) is not None:
             Client.ACTIVE_CLIS.pop(client_id)
         # Update server task output (? test ?)
-        Manager().server_task_msg(','.join(list(Client.ACTIVE_CLIS)))
+        Manager().task_msg('server', ','.join(list(Client.ACTIVE_CLIS)))
 
     def __del__(self):
         """Client GC collect"""
@@ -158,32 +171,23 @@ class WebCli(Client, WebEngine):
 
     async def run_web(self):
         # Update server task output
-        Manager().server_task_msg(','.join(list(Client.ACTIVE_CLIS)))
+        Manager().task_msg('server', ','.join(list(Client.ACTIVE_CLIS)))
 
         # Run async connection handling
         while self.connected:
             try:
                 # Read request msg from client
-                state, request = await self.read()
-                if state:
+                state, request = await self.read(decoding=None)
+                if state or not request:
+                    break
+                if not await self.response(request):
                     break
-                await self.response(request)
             except Exception as e:
-                errlog_add(f"[ERR] Client.run_web: {e}")
+                syslog(f"[ERR] Client.run_web: {e}")
                 break
         # Close connection
         await self.close()
 
-    @staticmethod
-    def register(endpoint, callback):
-        # AUTO ENABLE webui when register (endpoint) called and webui is False
-        if not cfgget('webui'):
-            from Config import cfgput
-            if cfgput('webui', True):  # SET webui to True
-                from machine import reset
-                reset()  # HARD RESET (REBOOT)
-        WebEngine.ENDPOINTS[endpoint] = callback
-
 
 class ShellCli(Client, Shell):
 
@@ -211,7 +215,7 @@ class ShellCli(Client, Shell):
             except:
                 # Maintain ACTIVE_CLIS - remove closed connection by peer.
                 Client.drop_client(self.client_id)
-                errlog_add(f"[WARN] ShellCli.send (auto-drop) {self.client_id}")
+                syslog(f"[WARN] ShellCli.send (auto-drop) {self.client_id}")
             # Send buffered data with async task - hacky
             if self.drain_event.is_set():
                 self.drain_event.clear()        # set drain busy (False)
@@ -245,7 +249,7 @@ class ShellCli(Client, Shell):
 
     async def run_shell(self):
         # Update server task output
-        Manager().server_task_msg(','.join(list(Client.ACTIVE_CLIS)))
+        Manager().task_msg('server', ','.join(list(Client.ACTIVE_CLIS)))
         # Init prompt
         await self.a_send(self.prompt())
         # Run async connection handling
@@ -254,19 +258,19 @@ class ShellCli(Client, Shell):
             try:
                 # Read request msg from client
                 state, request = await self.read()
-                if state:
+                if state or request in ('exit', ''):
                     break
                 # Run micrOS shell with request string
                 Client.console("[ShellCli] --- #Run shell")
                 # Shell -> True (OK) or False (NOK) -> NOK->Close session (auth Failed, etc.)
                 _exit = not await self.shell(request)
             except Exception as e:
-                errlog_add(f"[ERR] Shell client: {e}")
+                syslog(f"[ERR] Shell client: {e}")
                 if "ECONNRESET" in str(e):
                     _exit = True  # exit_loop
                 else:
                     await self.a_send("[HA] Critical error - disconnect & hard reset")
-                    errlog_add("[ERR] Socket critical error - reboot")
+                    syslog("[ERR] Socket critical error - reboot")
                     await self.reboot()
             if _exit:
                 collect()
