@@ -10,18 +10,19 @@ Designed by Marcell Ban aka BxNxM
 #################################################################
 from sys import modules
 from json import dumps
+from re import match
 import uasyncio as asyncio
 from micropython import schedule
 from utime import ticks_ms, ticks_diff
-from Debug import console_write, errlog_add
+from Debug import console_write, syslog
 from Config import cfgget
 from Network import sta_high_avail
 
 try:
-    from gc import collect
+    from gc import collect as gcollect
 except ImportError:
     console_write("[SIMULATOR MODE GC IMPORT]")
-    from simgc import collect
+    from simgc import collect as gcollect
 
 #################################################################
 #                Implement custom task class                    #
@@ -43,18 +44,20 @@ class TaskBase:
         self.done = asyncio.Event()  # Store task done state
         self.out = ""                # Store task output
 
-    @staticmethod
-    def is_busy(tag:str) -> bool:
+    ######  BASE METHODS FOR CHILD CLASSES  ####
+    def _create(self, callback:callable) -> dict:
         """
-        Check task is busy by tag
-        :param tag: for task selection
+        Create async task and register it to TASKS dict by tag
+        :param callback: coroutine function
         """
-        task = TaskBase.TASKS.get(tag, None)
-        # return True: busy OR False: not busy (inactive)
-        return bool(task is not None and not task.done.is_set())
+        # Create async task from coroutine function
+        self.task = asyncio.get_event_loop().create_task(callback)
+        # Store Task object by key - for task control
+        TaskBase.TASKS[self.tag] = self
+        return {self.tag: "Starting"}
 
     @staticmethod
-    def task_gc():
+    def _task_gc():
         """
         Automatic passive task deletion over QUEUE_SIZE
         """
@@ -63,7 +66,18 @@ class TaskBase:
         if len(passive) >= keep:
             for i in range(0, len(passive)-keep+1):
                 del TaskBase.TASKS[passive[i]]
-            collect()  # GC collect
+            gcollect()
+
+    ######  PUBLIC TASK METHODS  #####
+    @staticmethod
+    def is_busy(tag:str) -> bool:
+        """
+        Check task is busy by tag
+        :param tag: for task selection
+        """
+        task = TaskBase.TASKS.get(tag, None)
+        # return True: busy OR False: not busy (inactive) OR None: not exists
+        return bool(task is not None and not task.done.is_set())
 
     def cancel(self) -> bool:
         """
@@ -75,15 +89,38 @@ class TaskBase:
                     self.task.cancel()  # Try to cancel task by asyncio
                 except Exception as e:
                     if "can't cancel self" != str(e):
-                        errlog_add(f"[WARN] IRQ Task cancel: {e}")
+                        syslog(f"[WARN] IRQ Task cancel: {e}")
                 self.__task_del()
             else:
                 return False
         except Exception as e:
-            errlog_add(f"[ERR] Task kill: {e}")
+            syslog(f"[ERR] Task kill: {e}")
             return False
         return True
 
+    @staticmethod
+    async def feed(sleep_ms=1):
+        """
+        Feed event loop
+        :param sleep_ms: in millisecond
+        """
+        # TODO?: feed WDT - auto restart when system is frozen
+        if sleep_ms <= 0:
+            return await asyncio.sleep(0.000_000_1)     # 0 means: 100ns (Absolute minimum)
+        return await asyncio.sleep_ms(sleep_ms)
+
+    async def await_result(self, timeout:int=5):
+        """
+        Wait for task completion with timeout
+        :param timeout: in seconds
+        """
+        try:
+            await asyncio.wait_for(self.done.wait(), timeout)
+        except asyncio.TimeoutError:
+            return "Timeout has beed exceeded"
+        return self.out
+
+    ######  PRIVATE LCM METHODS  #####
     def __task_del(self, keep_cache=False):
         """
         Delete task from TASKS
@@ -92,24 +129,13 @@ class TaskBase:
         if self.tag in TaskBase.TASKS:
             if not keep_cache:              # True - In case of destructor
                 del TaskBase.TASKS[self.tag]
-        collect()                           # GC collect
-
-    @staticmethod
-    async def feed(sleep_ms=1):
-        """
-        Feed event loop
-        :param sleep_ms: in millisecond
-        """
-        # TODO: feed WDT - preemptive cooperative multitasking aka reboot if no feed until X time period
-        if sleep_ms <= 0:
-            return await asyncio.sleep(0.000_000_1)     # 0 means: 100ns (Absolute minimum)
-        return await asyncio.sleep_ms(sleep_ms)
+        gcollect()
 
     def __del__(self):
         try:
             self.__task_del(keep_cache=True)
         except Exception as e:
-            errlog_add(f"[ERR] TaskBase.__del__: {e}")
+            syslog(f"[ERR] TaskBase.__del__: {e}")
 
 
 class NativeTask(TaskBase):
@@ -118,7 +144,7 @@ class NativeTask(TaskBase):
     - could be built in function or custom code from load modules
     """
 
-    def create(self, callback:callable=None, tag:str=None) -> bool:
+    def create(self, callback:callable=None, tag:str=None) -> dict:
         """
         Create async task with coroutine callback (no queue limit check!)
         + async socket server task
@@ -127,15 +153,11 @@ class NativeTask(TaskBase):
         """
         # Create task tag
         self.tag = f"aio.{ticks_ms()}" if tag is None else tag
-        if TaskBase.is_busy(self.tag):
+        if self.is_busy(self.tag):
             # Skip task if already running
-            return False
-
-        # Start task with coroutine callback
-        self.task = asyncio.get_event_loop().create_task(callback)
-        # Store Task object by key - for task control
-        TaskBase.TASKS[self.tag] = self
-        return True
+            return {self.tag: "Already running"}
+        # Create task with coroutine callback
+        return super()._create(callback)
 
     def __enter__(self):
         """
@@ -152,7 +174,7 @@ class NativeTask(TaskBase):
         Helper function for Task creation in Load Modules
         [HINT] Use python with feature to utilize this feature
         """
-        self.task_gc()    # Task pool cleanup
+        self._task_gc()    # Task pool cleanup
         self.done.set()
 
 
@@ -168,7 +190,7 @@ class MagicTask(TaskBase):
         self.__inloop = False        # [LM] Task while loop for LM callback
         self.__sleep = 20            # [LM] Task while loop - async wait (proc feed) [ms]
 
-    def create(self, callback:list=None, loop:bool=None, sleep:int=None) -> bool:
+    def create(self, callback:list=None, loop:bool=None, sleep:int=None) -> dict:
         """
         Create async task with function callback (with queue limit check)
         - wrap (sync) function into async task (task_wrapper)
@@ -178,20 +200,16 @@ class MagicTask(TaskBase):
         """
         # Create task tag
         self.tag = '.'.join(callback[0:2])
-        if TaskBase.is_busy(self.tag):
+        if self.is_busy(self.tag):
             # Skip task if already running
-            return False
-
+            return {self.tag: "Already running"}
         # Set parameters for async wrapper
         self.__callback = callback
         self.__inloop = self.__inloop if loop is None else loop
         # Set sleep value for async loop - optional parameter with min sleep limit check (20ms)
         self.__sleep = self.__sleep if sleep is None else sleep if sleep > 19 else self.__sleep
-
-        self.task = asyncio.get_event_loop().create_task(self.__task_wrapper())
-        # Store Task object by key - for task control
-        TaskBase.TASKS[self.tag] = self
-        return True
+        # Create task with coroutine callback
+        return super()._create(self.__task_wrapper())
 
     async def __task_wrapper(self):
         """
@@ -206,7 +224,7 @@ class MagicTask(TaskBase):
             state, self.out = _exec_lm_core(self.__callback)
             if not state or not self.__inloop:
                 break
-        self.task_gc()    # Task pool cleanup
+        self._task_gc()    # Task pool cleanup
         self.done.set()
 
     def cancel(self):
@@ -240,7 +258,7 @@ class Manager:
             cls.INSTANCE._initialized = False
             # Set async event loop exception handler
             asyncio.get_event_loop().set_exception_handler(lambda loop=None, context=None:
-                                                           errlog_add(f"[aio] exception: {loop}:{context}"))
+                                                           syslog(f"[aio] exception: {loop}:{context}"))
         return cls.INSTANCE
 
     def __init__(self):
@@ -265,7 +283,7 @@ class Manager:
         """
         if Manager._queue_len() >= TaskBase.QUEUE_SIZE:
             msg = f"[aio] Task queue full: {TaskBase.QUEUE_SIZE}"
-            errlog_add(msg)
+            syslog(msg)
             raise Exception(msg)
 
     async def idle_task(self):
@@ -287,22 +305,26 @@ class Manager:
                 delta_rate = int(((ticks_diff(ticks_ms(), t) / 300) - 1) * 100)
                 Manager.LOAD = int((Manager.LOAD + delta_rate) / 2)  # Average - smooth
                 # [2] NETWORK AUTO REPAIR
-                if self.idle_counter > 200:  # ~120 sec
+                if self.idle_counter > 300:  # ~ 3 min
                     self.idle_counter = 0    # Reset counter
-                    # Check and fix STA network (example: after power outage - micrOS boards boots faster then router)
+                    # Check and fix STA network (reboot if target ssid is available not yet connected)
                     sta_high_avail()
                 self.idle_counter += 1  # Increase counter
         except Exception as e:
-            errlog_add(f"[ERR] Idle task exists: {e}")
+            syslog(f"[ERR] Idle task exists: {e}")
         my_task.done.set()
 
     @staticmethod
-    def create_task(callback, tag:str=None, loop:bool=False, delay:int=None):
+    def create_task(callback, tag:str=None, loop:bool=False, delay:int=None) -> dict:
         """
-        Primary interface
-        Generic task creator method
-            Create async Task with coroutine/list(lm call) callback
-        :param callback: list|callable
+        Primary interface of micrOS Generic task creator method
+        :param tag: task unique identifier
+        NativeTask:
+            :param callback: callable, coroutine to start a task
+        MagicTask with queue limiter:
+            :param callback: list of staring (command)
+            :param loop: MagicTask looping parameter
+            :param delay: MagicTask delay parameter
         """
         if isinstance(callback, list):
             # Check queue if task is Load Module
@@ -362,7 +384,7 @@ class Manager:
         return '\n'.join(output)
 
     @staticmethod
-    def kill(tag):
+    def kill(tag:str) -> (bool, str):
         """
         Primary interface
         Kill/terminate async task
@@ -374,7 +396,7 @@ class Manager:
             try:
                 return False if to_kill is None else to_kill.cancel()
             except Exception as e:
-                errlog_add(f"[ERR] Task kill: {e}")
+                syslog(f"[ERR] Task kill: {e}")
                 return False
 
         # Handle task group kill (module.*)
@@ -400,15 +422,23 @@ class Manager:
         try:
             asyncio.get_event_loop().run_forever()
         except Exception as e:
-            errlog_add(f"[aio] loop stopped: {e}")
+            syslog(f"[aio] loop stopped: {e}")
             asyncio.get_event_loop().close()
 
     @staticmethod
-    def server_task_msg(msg):
-        server_task = TaskBase.TASKS.get('server', None)
-        if server_task is None:
-            return
-        server_task.out = msg
+    def task_msg(tag:str, msg:str=None) -> bool|str:
+        """
+        Set/Get task message (for server virtual task, etc.)
+        """
+        _task = TaskBase.TASKS.get(tag, None)
+        if _task is None:
+            return False
+        # Get task output
+        if tag is None:
+            return _task.out
+        # Set task output
+        _task.out = msg
+        return True
 
 
 #################################################################
@@ -429,8 +459,10 @@ def exec_builtins(func):
             # ... >json               - command output format option
             # ... >>node01.local      - intercon: command execution on remote device by hostname/IP address
             arg_list, json_flag = (arg_list[:-1], True) if arg_list[-1] == '>json' else (arg_list, False)
-            arg_list, intercon_target = (arg_list[:-1], arg_list[-1].replace(">>", "")) if arg_list[-1].startswith('>>') else (arg_list, None)
             json_flag = jsonify if isinstance(jsonify, bool) else json_flag
+            arg_list, intercon_target = ((arg_list[:-1], arg_list[-1].replace(">>", ""))
+                                          if match(r'^>>[A-Za-z0-9._-]+$', arg_list[-1])
+                                          else (arg_list, None))
 
             # INTERCONNECT
             if intercon_target:
@@ -441,7 +473,7 @@ def exec_builtins(func):
                     out = Manager.INTERCON(host=intercon_target, cmd=arg_list)
                 except Exception as e:
                     out = {}
-                    errlog_add(f"[ERR] Intercon: {e}")
+                    syslog(f"[ERR] Intercon: {e}")
                 return True, out
 
             # MODULES
@@ -455,11 +487,11 @@ def exec_builtins(func):
                 if arg_len > 1 and 'list' == arg_list[1]:
                     on, off = Manager.list_tasks(json=json_flag)
                     # RETURN:    JSON mode                                                   Human readable mode with cpu & queue info
-                    return (True, {'active': on[3:], 'inactive': off}) if json_flag else (True, '\n'.join(on) + '\n' + '\n'.join(off) + '\n')
+                    return (True, dumps({'active': on[3:], 'inactive': off})) if json_flag else (True, '\n'.join(on) + '\n' + '\n'.join(off) + '\n')
                 # task kill <taskID> / task show <taskID>
                 if arg_len > 2:
                     if 'kill' == arg_list[1]:
-                        state, msg = Manager.kill(tag=arg_list[2])
+                        _, msg = Manager.kill(tag=arg_list[2])
                         return True, msg
                     if 'show' == arg_list[1]:
                         return True, Manager.show(tag=arg_list[2])
@@ -467,6 +499,8 @@ def exec_builtins(func):
 
             # Call the decorated function with the additional flag
             return func(arg_list, json_flag)
+        return False, None
+
     return wrapper
 
 
@@ -490,15 +524,9 @@ def lm_exec(arg_list:list, jsonify:bool=None):
         delay = int(delay) if delay.isdigit() else None
         # Create and start async lm task
         try:
-            state = Manager.create_task(arg_list, loop=loop, delay=delay)
+            return True, Manager.create_task(arg_list, loop=loop, delay=delay)
         except Exception as e:
-            # Valid & handled task command
-            return True, str(e)
-        tag = '.'.join(arg_list[0:2])
-        # Valid & handled task command
-        if state:
-            return True, f"Start {tag}"
-        return True, f"{tag} is Busy"
+            return False, {".".join(arg_list[0:2]): str(e)}
 
     # [2] Sync "realtime" task execution
     state, out = _exec_lm_core(arg_list, jsonify)
@@ -514,7 +542,7 @@ def _exec_lm_core(cmd_list, jsonify):
         [2] function
         [3...] parameters (separator: space)
     :param jsonify: request json output
-    Return Bool(OK/NOK), STR(Command output)
+    Return Bool(OK/NOK), Str(Command output)
     """
 
     def _func_params(param):
@@ -567,7 +595,7 @@ def _exec_lm_core(cmd_list, jsonify):
                 # UNLOAD MODULE IF MEMORY ERROR HAPPENED + gc.collect
                 if lm_mod in modules:
                     del modules[lm_mod]
-                collect()
+                gcollect()
             # LM EXECUTION ERROR
             return False, f"Core error: {lm_mod}->{lm_func}: {e}"
     return False, "Shell: for hints type help.\nShell: for LM exec: [1](LM)module [2]function [3...]optional params"
@@ -598,13 +626,13 @@ def exec_lm_pipe(taskstr):
             return True
         # Execute individual commands - msgobj->"/dev/null"
         for cmd in (cmd.strip().split() for cmd in taskstr.split(';') if len(cmd) > 0):
-            if len(cmd) > 0 and cmd[0].startswith("#"):
+            if cmd[0].startswith("#"):
                 console_write(f"[SKIP] exec_lm_pipe: {' '.join(cmd)}")
                 continue
             if not lm_exec(cmd)[0]:
-                errlog_add(f"[WARN] exec_lm_pipe: {cmd}")
+                syslog(f"[WARN] exec_lm_pipe: {' '.join(cmd)}")
     except Exception as e:
-        errlog_add(f"[ERR] exec_lm_pipe {taskstr}: {e}")
+        syslog(f"[ERR] exec_lm_pipe {taskstr}: {e}")
         return False
     return True
 
@@ -617,5 +645,5 @@ def exec_lm_pipe_schedule(taskstr):
         schedule(exec_lm_pipe, taskstr)
         return True
     except Exception as e:
-        errlog_add(f"[ERR] exec_lm_pipe_schedule: {e}")
+        syslog(f"[ERR] exec_lm_pipe_schedule: {e}")
         return False
