@@ -1,5 +1,6 @@
 """
 Module is responsible for invoke micrOS or recovery webrepl mode
+[IMPORTANT] This module must never use any micrOS specific functions in main scope.
 
 Designed by Marcell Ban aka BxNxM
 """
@@ -11,11 +12,6 @@ try:
     import traceback
 except:
     traceback = None
-try:
-    from Debug import errlog_add
-except Exception as e:
-    print(f"[loader] Import error: {e}")
-    errlog_add = None
 from machine import reset
 
 
@@ -59,6 +55,8 @@ def _is_micrOS():
 
 def __recovery_mode():
     # Recovery/Update mode (webrepl) - dependencies: Network, ConfigHandler
+    from sys import path
+    path.insert(0, "/modules")
     from Network import auto_nw_config
     from Config import cfgget
     pwd = cfgget('appwd')                       # Get pwd from config
@@ -70,9 +68,7 @@ def __recovery_mode():
         import webrepl
         webrepl.start(password=pwd)
     except Exception as e:
-        if callable(errlog_add):
-            errlog_add(f"[ERR][micrOSloader] webrepl failed: {e}")
-        print("[loader] Reset .if_mode to micros and reboot")
+        print(f"[loader] webrepl failed: {e} - Reset .if_mode to micros and reboot")
         with open('.if_mode', 'w') as f:
             f.write("micros")
         # Reboot machine
@@ -106,7 +102,7 @@ def __auto_restart_event():
         if trigger_is_active and _is_micrOS():
             print("[loader][ota-rebooter][micros][trigger: True] OTA was finished - reboot")
             # Create cleanup indicator file for ConfigHandler
-            with open('cleanup.pds', 'w') as f:
+            with open('.cleanup', 'w') as f:
                 f.write('')
             # Reboot machine
             reset()
@@ -126,8 +122,6 @@ def main():
             # Handle micrOS system crash (never happened...but) -> webrepl mode default pwd: ADmin123
             print(f"[loader][main mode] micrOS start failed: {e}")
             print("[loader][main mode] -> [recovery mode]")
-            if callable(errlog_add):
-                errlog_add(f"[ERR][micrOSloader] start failed: {e}")
     # Recovery aka webrepl mode
     __recovery_mode()
     __auto_restart_event()
