@@ -13,12 +13,14 @@ try:
     from .lib import LocalMachine
     from .lib.TerminalColors import Colors
     from .lib.SerialDriverHandler import install_usb_serial_driver
+    from .lib.MicrosFiles import micros_resource_list
 except Exception as e:
     print("Import warning __name__:{}: {}".format(__name__, e))
     from DevEnvCompile import Compile
     from lib import LocalMachine
     from lib.TerminalColors import Colors
     from lib.SerialDriverHandler import install_usb_serial_driver
+    from lib.MicrosFiles import micros_resource_list
 
 
 class USB(Compile):
@@ -33,6 +35,7 @@ class USB(Compile):
         self.micrOS_node_config_archive = os.path.join(MYPATH, "user_data/node_config_archive")
         self.node_config_profiles_path = os.path.join(MYPATH, "../micrOS/release_info/node_config_profiles/")
         self.esptool_interface = self.get_valid_esptool_cmd()
+        self.micrOS_node_config_path = "config/node_config.json"
         self.dev_types_and_cmds = \
             {'esp32':
                  {'erase': '{esptool_interface} --port {dev} erase_flash',
@@ -207,6 +210,38 @@ class USB(Compile):
             self.console("Deployment failed.\n{} - {}".format(stdout, stderr), state='err')
             return False
 
+    def _mkdir_on_dev(self, folders:list):
+        mpremote_cmd = self.dev_types_and_cmds[self.selected_device_type]['mpremote_cmd']
+        device = self.get_devices()[0]
+        if mpremote_cmd is None:
+            # Legacy ampy command (esp32 auto reboot tolerance...)
+            mkdir_cmd = self.dev_types_and_cmds[self.selected_device_type]['ampy_cmd'].format(dev=device, args=f'mkdir')
+        else:
+            mkdir_cmd = f'{mpremote_cmd} fs mkdir'
+
+        status = 0
+        for folder in folders:
+            _mkdir_cmd = f"{mkdir_cmd} {folder}"
+            self.console(f"Create directory on device: {_mkdir_cmd}")
+            if self.dry_run:
+                pass
+            else:
+                try:
+                    exitcode, stdout, stderr = LocalMachine.CommandHandler.run_command(_mkdir_cmd, shell=True)
+                    if exitcode != 0:
+                        verdict = stdout + stderr
+                        if "File exists" in verdict or "Directory already exists" in verdict:
+                            exitcode = 0
+                        else:
+                            self.console(f"MKDIR ERROR:\n{stdout}\n{stderr}", state="err")
+                except Exception as e:
+                    self.console(f"MKDIR ERROR {_mkdir_cmd}: {e}", state="err")
+                    exitcode = 1
+                status += exitcode
+
+        return True if status == 0 else False
+
+
     def put_micros_to_dev(self):
         self.select_board_n_micropython()
         status = True
@@ -223,17 +258,20 @@ class USB(Compile):
                 self.console(f"... wait for reset {10-k} sec", state='imp')
                 time.sleep(1)
 
+        # Parse micrOS resources with folders
+        _source_to_put_device, dir_list_to_create = micros_resource_list(self.precompiled_micrOS_dir_path)
+        self.console(f"CREATE FOLDERS: {dir_list_to_create}", state="ok")
+        # Create sub folders
+        if not self._mkdir_on_dev(dir_list_to_create):
+            self.console(f"Error creating directories on device: {dir_list_to_create}")
+            sys.exit(1)
+        # Generate resource list to be put on the device
+        source_to_put_device = list([s.replace(self.precompiled_micrOS_dir_path + os.sep, '') for s in _source_to_put_device])
+        # Set source order - main, boot
+        source_to_put_device.append(source_to_put_device.pop(source_to_put_device.index("main.py")))
+
         mpremote_cmd = self.dev_types_and_cmds[self.selected_device_type]['mpremote_cmd']
         device = self.get_devices()[0]
-        source_to_put_device = LocalMachine.FileHandler.list_dir(self.precompiled_micrOS_dir_path)
-        # Set source order - main, boot
-        source_to_put_device.append(source_to_put_device.pop(source_to_put_device.index('main.py')))
-        try:
-            # PIP deployment generates this ...
-            source_to_put_device.remove('__pycache__')      # remove if accidentally left here
-        except:
-            pass
-
         # Change workdir
         workdir_handler = LocalMachine.SimplePopPushd()
         workdir_handler.pushd(self.precompiled_micrOS_dir_path)
@@ -243,7 +281,7 @@ class USB(Compile):
             self.console("[{}%] micrOS deploy via USB - {}".format(percent, device))
             if mpremote_cmd is None:
                 # Legacy ampy command (esp32 auto reboot tolerance...)
-                command = self.dev_types_and_cmds[self.selected_device_type]['ampy_cmd'].format(dev=device, args=f'put {source}')
+                command = self.dev_types_and_cmds[self.selected_device_type]['ampy_cmd'].format(dev=device, args=f'put {source} /{source}')
             else:
                 command = f'{mpremote_cmd} fs cp {source} :{source}'     # new mpremote <1.24.1
             if ' ' in source:
@@ -260,17 +298,17 @@ class USB(Compile):
     def update_micros_via_usb(self, force=False):
         self.select_board_n_micropython()
         exitcode, stdout, stderr = self.__get_node_config()
-        print(self.__get_node_config())
         if exitcode == 0:
             self.console("Get Node config (node_config.json):")
             pprint.PrettyPrinter(indent=4).pprint(json.loads(stdout))
             repo_version, node_version = self.get_micrOS_version(stdout)
             self.console("Repo version: {} Node_version: {}".format(repo_version, node_version))
             if repo_version != node_version or force:
+                self._cleanup_precompiled_dir()
                 self.console("Update necesarry {} -> {}".format(node_version, repo_version), state='ok')
                 state = self.__override_local_config_from_node(node_config=stdout)
                 if state:
-                    self.deploy_micros(restore=False)
+                    self.deploy_micros(restore_config=False, cleanup_workdir=False)
                 else:
                     self.console("Saving node config failed - SKIP update/redeploy", state='err')
             else:
@@ -284,17 +322,17 @@ class USB(Compile):
         self.execution_verdict.append("[OK] usb_update was finished")
         return True
 
-    def deploy_micros(self, restore=True, purge_conf=False):
+    def deploy_micros(self, restore_config=True, cleanup_workdir=True):
         """
         Clean board deployment with micropython + micrOS
-        :param restore: restore and create node config
-        :param purge_conf: purge node config - deletion
+        :param restore_config: restore and create node config
+        :param cleanup_workdir: clean up workdir as part of precompile
         :return: None
         """
         self.select_board_n_micropython()
-        if purge_conf:
-            self._purge_node_config_from_workdir()
-        if restore:
+        self.precompile_micros(cleanup=cleanup_workdir)
+
+        if restore_config:
             self._restore_and_create_node_config()
 
         is_erased = False
@@ -306,9 +344,7 @@ class USB(Compile):
                 break
         if is_erased:
             if self.deploy_micropython_dev():
-                time.sleep(2)
-                self.precompile_micros()
-                time.sleep(2)
+                time.sleep(3)
                 self.put_micros_to_dev()
                 self._archive_node_config()
             else:
@@ -348,7 +384,7 @@ class USB(Compile):
             # List USB devices on Windows
             import serial.tools.list_ports as serial_port_list      # Import here (only windows...), package not exists on some platforms
             ports = list(serial_port_list.comports())
-            win_known_devices = ("CP210", "CH340", "CH343")
+            win_known_devices = ("CP210", "CH340", "CH343", "CH9102")
             for item in ports:
                 self.console(f'[Win] Com device: {item.description}')
                 if any(device in str(item.description) for device in win_known_devices):
@@ -378,7 +414,7 @@ class USB(Compile):
     #############################
 
     def _purge_node_config_from_workdir(self):
-        path = os.path.join(self.precompiled_micrOS_dir_path, 'node_config.json')
+        path = os.path.join(self.precompiled_micrOS_dir_path, self.micrOS_node_config_path)
         LocalMachine.FileHandler().remove(path, ignore=False)
 
     def _restore_and_create_node_config(self):
@@ -394,24 +430,22 @@ class USB(Compile):
             self.console("  [{}{}{}] {}".format(Colors.BOLD, index, Colors.NC, conf))
         self.console("  [{}{}{}] {}".format(Colors.BOLD, index + 1, Colors.NC, 'NEW'))
         self.console("  [{}{}{}] {}".format(Colors.BOLD, index + 2, Colors.NC, 'SKIP'))
-        conf_list.append(os.path.join('node_config.json'))
+        conf_list.append(self.micrOS_node_config_path)
         conf_list.append(os.path.join('SKIP'))
         selected_index = int(input("Select index: "))
         # Use (already existing) selected config to restore
         selected_config = conf_list[selected_index]
-        if '-' in selected_config:
+        target_path = os.path.join(self.precompiled_micrOS_dir_path, self.micrOS_node_config_path)
+        if selected_config.endswith(".json"):
             # Restore saved config
-            target_path = os.path.join(self.precompiled_micrOS_dir_path, selected_config.split('-')[1])
             source_path = os.path.join(self.micrOS_node_config_archive, selected_config)
         elif selected_index == len(conf_list) - 1:
             # SKIP restore config - use the local version in mpy-micrOS folder
-            target_path = os.path.join(self.precompiled_micrOS_dir_path, 'node_config.json')
             source_path = None
         else:
             # Create new config - from micrOS folder path -> mpy-micrOS folder
-            target_path = os.path.join(self.precompiled_micrOS_dir_path, selected_config)
             source_path = os.path.join(self.micrOS_dir_path, selected_config)
-        self.console("Restore config: {} -> {}".format(source_path, target_path))
+        self.console(f"Restore config: {source_path} -> {target_path}")
         if source_path is not None:
             LocalMachine.FileHandler.copy(source_path, target_path)
 
@@ -448,9 +482,11 @@ class USB(Compile):
         else:
             self.console("Profile was selected: {}{}{}".format(Colors.OK, profile_list[int(profile)], Colors.NC))
         # Read default conf
-        default_conf_path = os.path.join(self.micros_sim_workspace, 'node_config.json')
+        default_conf_path = os.path.join(self.micrOS_dir_path, self.micrOS_node_config_path)
         if not os.path.isfile(default_conf_path):
-            self.micrOS_sim_default_conf_create()
+            if not self.__generate_default_config():
+                self.console(f"Missing default config: {default_conf_path}", state="warn")
+                return None
         with open(default_conf_path, 'r') as f:
             default_conf_dict = json.load(f)
         # Read profile
@@ -515,10 +551,9 @@ class USB(Compile):
         create_default_config_command = "{} Config.py".format(self.python_interpreter)
         if not self.dry_run:
             # Remove actual defualt config
-            LocalMachine.FileHandler.remove(os.path.join(self.micrOS_dir_path, 'node_config.json'))
+            LocalMachine.FileHandler.remove(os.path.join(self.micrOS_dir_path, self.micrOS_node_config_path))
             # Create default config
-            exitcode, stdout, stderr = LocalMachine.CommandHandler.run_command(create_default_config_command,
-                                                                               shell=True)
+            exitcode, stdout, stderr = LocalMachine.CommandHandler.run_command(create_default_config_command, shell=True)
         else:
             exitcode = 0
         # Restore workdir
@@ -547,7 +582,7 @@ class USB(Compile):
 
     def __validate_json(self):
         is_valid = True
-        local_config_path = os.path.join(self.precompiled_micrOS_dir_path, 'node_config.json')
+        local_config_path = os.path.join(self.precompiled_micrOS_dir_path, self.micrOS_node_config_path)
         try:
             if os.path.isfile(local_config_path):
                 with open(local_config_path, 'r') as f:
@@ -559,6 +594,9 @@ class USB(Compile):
         return is_valid
 
     def __safe_execute_mpremote_cmd(self, command, source, retry=8):
+        if sys.platform.startswith('win'):
+            # Because windows is a shit... python commands requires unix like separators
+            command = command.replace('\\', '/')
         retry_orig = retry
         status = False
         for retry in range(1, retry_orig):
@@ -613,24 +651,34 @@ class USB(Compile):
         return processid
 
     def __get_node_config(self):
+
+        def _get_config(path):
+            mpremote_cmd = self.dev_types_and_cmds[self.selected_device_type]['mpremote_cmd']
+            if mpremote_cmd is None:
+                # Legacy ampy command (esp32 auto reboot tolerance...)
+                _command = (self.dev_types_and_cmds[self.selected_device_type]['ampy_cmd']
+                           .format(dev=device, args=f'get {path}'))
+            else:
+                _command = f'{mpremote_cmd} fs cat {path}'  # new mpremote <1.24.1
+            _exitcode, _stdout, _stderr = LocalMachine.CommandHandler.run_command(_command, shell=True)
+            return _exitcode, _stdout, _stderr
+
         device = self.get_devices()[0]
         self.console(f"Get node config over USB: {device}")
-        mpremote_cmd = self.dev_types_and_cmds[self.selected_device_type]['mpremote_cmd']
-        if mpremote_cmd is None:
-            # Legacy ampy command (esp32 auto reboot tolerance...)
-            command = self.dev_types_and_cmds[self.selected_device_type]['ampy_cmd'].format(dev=device, args='get node_config.json')
+        if self.dry_run:
+            exitcode, stdout, stderr = 0, '{"key": "Dummy stdout"}', ''
         else:
-            command = f'{mpremote_cmd} fs cat node_config.json'     # new mpremote <1.24.1
-        if not self.dry_run:
-            exitcode, stdout, stderr = LocalMachine.CommandHandler.run_command(command, shell=True)
+            exitcode, stdout, stderr = _get_config("node_config.json")                  # Legacy
+            if exitcode != 0:
+                exitcode, stdout, stderr = _get_config("/" + self.micrOS_node_config_path)    # New
             self._archive_node_config()
-        else:
-            exitcode = 0
-            stdout = '{"key": "Dummy stdout"}'
-            stderr = ''
+
         if '\n' in stdout:
             stdout = stdout.strip().splitlines()
-            stdout = str([line for line in stdout if '{' in line and '}' in line][0])
+            try:
+                stdout = str([line for line in stdout if '{' in line and '}' in line][0])
+            except Exception as ejson:
+                raise Exception(f"Invalid json format from device: {ejson}")
         return exitcode, stdout, stderr
 
     def backup_node_config(self):
@@ -645,12 +693,12 @@ class USB(Compile):
                 if state:
                     self._archive_node_config()
                     return True
-        self.console("exitcode: {}\n{}\n{}".format(exitcode, stdout, stderr))
+            self.console("exitcode: {}\n{}\n{}".format(exitcode, stdout, stderr))
         return False
 
     def _archive_node_config(self):
         self.console("ARCHIVE NODE_CONFIG.JSON")
-        local_node_config = os.path.join(self.precompiled_micrOS_dir_path, 'node_config.json')
+        local_node_config = os.path.join(self.precompiled_micrOS_dir_path, self.micrOS_node_config_path)
         if os.path.isfile(local_node_config):
             with open(local_node_config, 'r') as f:
                 node_devfid = json.load(f)['devfid']
@@ -662,8 +710,9 @@ class USB(Compile):
                 LocalMachine.FileHandler.copy(local_node_config, archive_node_config)
 
     def __override_local_config_from_node(self, node_config=None):
-        node_config_path = os.path.join(self.precompiled_micrOS_dir_path, 'node_config.json')
-        self.console("Overwrite node_config.json with connected node config: {}".format(node_config_path), state='ok')
+        self.ensure_precompiled_target_dir("config")
+        node_config_path = os.path.join(self.precompiled_micrOS_dir_path, self.micrOS_node_config_path)
+        self.console(f"Overwrite node_config.json with connected node config: {node_config_path}", state='ok')
         if not self.dry_run and node_config is not None:
             with open(node_config_path, 'w') as f:
                 f.write(node_config)
