@@ -168,38 +168,38 @@ def micrOS_config_set():
 
 
 def micrOS_bgjob_one_shot_check():
-    info = "[ST] Run micrOS BgJob check [system clock &]"
+    info = "[ST] Run async microTask check [system clock &]"
     print(info)
-
     # Initial task cleanup...
     CLIENT.execute(['task kill system.clock'])
-
-    for _ in range(0, 2):
-        cmd_list = ['system clock &']
-        output = CLIENT.execute(cmd_list)
-        time.sleep(1)
-        if output[0]:
-            if 'Start system.clock' not in output[1].strip():
-                return False, f'{info} + not expected return: {output[1]}'
-    return True, info
+    time.sleep(1)
+    cmd_list = ['system clock &']
+    output = CLIENT.execute(cmd_list)
+    if output[0]:
+        # Legacy return OR New dict return
+        if 'Start system.clock' in output[1].strip() or "{'system.clock': 'Starting'}" in output[1].strip():
+            return True, info
+    return False, f'{info} + not expected return: {output[1]}'
 
 
 def micrOS_bgjob_loop_check():
-    info = "[ST] Run micrOS Async Task check [system clock &&] + task kill"
+    info = "[ST] Run async microTask check [system clock &&] + task kill"
     print(info)
 
     # Start background task loop
     cmd_list = ['system clock &&']
     output = CLIENT.execute(cmd_list)
     if output[0]:
-        if 'Start system.clock' not in output[1].strip():
+        # Legacy return OR New dict return
+        if not ('Start system.clock' in output[1].strip() or "{'system.clock': 'Starting'}" in output[1]):
             return False, f'[Start Task error] {info} + not expected return: {output[1]}'
 
     # Attempt to overload background thread
     cmd_list = ['system clock &&']
     output = CLIENT.execute(cmd_list)
     if output[0]:
-        if 'system.clock is Busy' not in output[1].strip():
+        # Legacy return OR New dict return
+        if not ('system.clock is Busy' in output[1].strip() or "{'system.clock': 'Already running'}" in output[1]):
             return False, f'[Overload task - run same] {info} + not expected return: {output[1]}'
 
     # Show task output by task tag
@@ -220,6 +220,7 @@ def micrOS_bgjob_loop_check():
     # Failed verdict
     return False, f'[Thread not stopped]{info} + not expected return: {output[1]}'
 
+
 def micrOS_task_list_check():
     info = "[ST] Run micrOS Task list feature check [task list][task list >json]"
     print(info)
@@ -243,6 +244,7 @@ def micrOS_task_list_check():
         print(f"{info} - task list >json error: {output[1]}")
     return True, info
 
+
 def micrOS_get_version():
     info = "[ST] Run micrOS get version [version]"
     print(info)
@@ -412,6 +414,10 @@ def check_intercon(host=None):
         except Exception as e:
             print(f"WARNING: cannot parse output as dir: {e}")
             data_dict = {'tag': None, 'verdict': f'{data}: {str(e)}'}
+        # Handle new syntax: {"taskID": "verdict"}
+        if data[0] and data_dict.get("tag") is None:
+            _ttag = list(data_dict.keys())[0]
+            data_dict = {'tag': _ttag, 'verdict': f'{list(data_dict.values())[0]}: task show {_ttag}'}
         return data[0], data_dict
 
     def _get_intercon_output(tag):
@@ -426,51 +432,51 @@ def check_intercon(host=None):
                 break
         return _state, _output
 
-    def run_intercon_hello(tout):
+    def run_intercon_hello(tout=8):
         nonlocal host
         cmd_list = [f'hello >>{host}']
-        _output = CLIENT.execute(cmd_list, tout=8)
-        _new_intercon = True
-        if "hello:" in _output[1]:  # TODO: remove...
-            # LEGACY WAY: FALLBACK
-            cmd_list = ['intercon sendcmd "{}" "hello" >json'.format(host)]
-            _output = CLIENT.execute(cmd_list, tout=tout)
-            _new_intercon = False
-        return _new_intercon, _output
+        _output = CLIENT.execute(cmd_list, tout=tout)
+        return _output
 
     info_msg = '[ST] Check device-device connectivity'
     print(info_msg)
     host = 'test.local' if host is None else host
-    new_intercon, output = run_intercon_hello(tout=8)
+    output = run_intercon_hello(tout=8)
     output = _convert_return_to_dict(output)
+
     device_was_found = False
     if output[0] is False or output[1] is None:
         output = 'Device was not found: {}:{}'.format(host, output)
         return False, output
-    elif output[1] == '[]':
+    if output[1] == '[]':
         # Valid input, device was not found
         output = 'Device was not found: {}:{}'.format(host, output)
         state = True, f'{info_msg}:\n\t\t{output}'
     elif len(output[1]) > 1 and "hello" in output[1]['verdict']:
         response_state, response = _get_intercon_output(output[1]['tag'])
         # Valid input on online device
-        output = "Device was found: {}:{} version: {}".format(host, f"{output}: {response}", "NEW" if new_intercon else "LEGACY")
-        state = True & response_state, f'{info_msg}:\n\t\t{output}'
+        output = "Device was found: {}:{}".format(host, f"{output}: {response}")
+        state = response_state, f'{info_msg}:\n\t\t{output}'
         device_was_found = True
     else:
-        state = False, output
+        state = False, f" InterCon Failed: {output}"
 
     if device_was_found:
         # DO Negative testing as well
         host = "notavailable.local"
-        _, output_neg = run_intercon_hello(tout=20)
+        output_neg = run_intercon_hello(tout=20)
+        if output_neg[0] and output_neg[1] == '':
+            # NO HOST TIMEOUT ...
+            output_neg = f'Device was not found (dhcp timeout): {host}:{output_neg}: {output_neg[1]}'
+            return True & state[0], f"{state[1]}\n\t\tNegative test: {output_neg}"
+        # Valid return on negative testing
         output_neg = _convert_return_to_dict(output_neg)
-        state_neg = False, output_neg
+        state_neg = False, f"Negative test failed: {output_neg}"
         if len(output_neg[1]) > 1 and "hello" in output_neg[1]['verdict']:
             response_state, response = _get_intercon_output(output_neg[1]['tag'])
             output_neg = f'Device was not found: {host}":{output_neg}: {response}'
-            state_neg = True & response_state, output_neg
-        return state[0] & state_neg[0], "{}\n\t\tNegative test: {}".format(state[1], state_neg[1])
+            state_neg = response_state, output_neg
+        return state[0] & state_neg[0], f"{state[1]}\n\t\tNegative test: {state_neg[1]}"
     return state
 
 
@@ -523,7 +529,7 @@ def disk_usage():
     # {"percent": 15.4, "fs_used": 323_584}
     _add_metrics('fs_percent', json_out.get('percent'))
     _add_metrics('fs_used_byte', json_out.get('fs_used'))
-    if json_out.get('fs_used') > 700_000:        # MEM USAGE WARNING INDICATOR: 700_000 bytes (700kb)
+    if json_out.get('fs_used') > 800_000:        # MEM USAGE WARNING INDICATOR: (800kb)
         return state, '[ST] {}WARNING{}: disk usage {}% ({} bytes)'.format(Colors.WARN, Colors.NC,
                                                                              json_out.get('percent'),
                                                                              json_out.get('fs_used'))
@@ -551,8 +557,8 @@ def webcli_test():
             out = CLIENT.execute(['conf', 'devip'], tout=TIMEOUT_SEC)
             if out[0] and out[1] is not None:
                 devip = out[1]
-                endpoints.append(f'http://{devip}')
                 endpoints.append(f'http://{devip}/rest')
+                endpoints.append(f'http://{devip}')
 
             for endpoint in endpoints:
                 _start_t = time.time()
@@ -562,12 +568,15 @@ def webcli_test():
                     delta_t = round(time.time() - _start_t, 2)
                     # Check if the request was successful
                     if not (response.status_code == 200 and ('<!DOCTYPE html>' in str(response.content) or '"micrOS"' in str(response.content))):
-                        verdict += f" Endpoint: {endpoint} [{Colors.ERR}NOK{Colors.NC}]({delta_t}s)"
-                        print(response.content)
-                        state = False
+                        if response.status_code == 400 and "Low memory" in str(response.content):
+                            verdict += f" Endpoint: {endpoint} - Low memory mode [{Colors.WARN}OK{Colors.NC}]({delta_t}s)"
+                            print(response.content)
+                        else:
+                            verdict += f" Endpoint: {endpoint} [{Colors.ERR}NOK{Colors.NC}]({delta_t}s)"
+                            print(response.content)
+                            state = False
                     else:
                         verdict += f" Endpoint: {endpoint} [{Colors.OK}OK{Colors.NC}]({delta_t}s)"
-
                         metrics_name = 'landingpage' if "." in endpoint.split('/')[-1] else endpoint.split('/')[-1]
                         _add_metrics(f"web_{metrics_name}_response_ms", int(delta_t*1000))
                 except Exception as e:
@@ -663,6 +672,7 @@ def app(devfid=None, pwd=None):
                'clean-reboot': after_st_reboot()
                }
 
+
     # Test Evaluation
     final_state = True
     ok_cnt = 0
