@@ -7,6 +7,9 @@ try:
 except:
     from TerminalColors import Colors as color
 
+
+ANSI_ESCAPE_RE = re.compile(r"\x1B\[[0-?]*[ -/]*[@-~]")
+
 def load_command_history(prompt_getter):
     """Optional command history feature"""
     try:
@@ -173,22 +176,33 @@ class micrOSClient:
 
     def __filter_preprompt(self, _data):
         if len(_data) == 0:
-            return
-        last_line = _data.strip().split('\n')[-1]
-        # get pre-prompt: >[configure]< prompt $
+            return _data
+
+        has_trailing_newline = _data.endswith('\n')
+        working = _data.rstrip('\n')
+        lines = working.split('\n') if working else ['']
+        last_line = lines[-1]
+
         if self.prompt is not None:
-            # Check prompt is in last line
-            if self.prompt in last_line:
-                # Check pre-prompt - remove prompt
-                x = last_line.replace(self.prompt, '')
-                # SET preprompt if preprompt exists
-                self.preprompt = x if len(x) > 0 else self.preprompt
-            # Pre-prompt remove and cancel preprompt modes
-            if self.preprompt in last_line:
-                _data = _data.replace(self.preprompt, "")
-            else:
-                self.preprompt = ""
-        return _data
+            prompt_index = last_line.find(self.prompt)
+            if prompt_index != -1:
+                raw_prefix = last_line[:prompt_index]
+                plain_prefix = ANSI_ESCAPE_RE.sub('', raw_prefix)
+
+                plain_prefix = plain_prefix.rstrip()
+                if plain_prefix:
+                    if not plain_prefix.endswith(' '):
+                        plain_prefix += ' '
+                    self.preprompt = plain_prefix
+                else:
+                    self.preprompt = ""
+
+                lines[-1] = last_line[prompt_index:]
+
+        rebuilt = '\n'.join(lines)
+        if has_trailing_newline:
+            rebuilt += '\n'
+        return rebuilt
 
     def __receive_data(self, read_timeout=20, stream=False):
         """
@@ -323,18 +337,26 @@ class micrOSClient:
                 return
 
         history = load_command_history(self.telnet_prompt)              # History: Beta feature
+        if history is not None:
+            history.prompt = self.telnet_prompt
         print(self.telnet_prompt, end="")
         is_empty = False                                                # Empty input support
         while True:
             try:
                 # INPUT HANDLING
+                if history is not None:
+                    history.prompt = self.telnet_prompt
                 cmd = input(self.telnet_prompt if is_empty else '')     # CANNOT contain prompt - it is coming back from response data
                 if len(cmd.strip()) == 0:
                     is_empty = True
+                    if history is not None:
+                        history.prompt = self.telnet_prompt
                     continue
                 is_empty = False
                 # SEND COMMAND
                 output = self.send_cmd(cmd, timeout=timeout, stream=True)
+                if history is not None:
+                    history.prompt = self.telnet_prompt
                 if not (history is None or output is None) and "Shell: for hints type help." not in output:   # History: Beta feature
                     history.add_history(cmd)
                 # OUTPUT HANDLING
