@@ -6,17 +6,12 @@ import os
 import threading
 import subprocess
 import time
-from PyQt5.QtWidgets import QPushButton
-import PyQt5.QtCore as QtCore
-from PyQt5.QtCore import pyqtSlot
-from PyQt5.QtWidgets import *
-from PyQt5.QtGui import QIcon
-from PyQt5.QtGui import QTextCursor
-from PyQt5.QtWidgets import QApplication, QPlainTextEdit
-from PyQt5.QtCore import QThread, pyqtSignal
-from PyQt5.QtGui import QFont
-from PyQt5 import QtGui
-from PyQt5.QtGui import QPixmap
+
+from PyQt5.QtWidgets import (QApplication, QPlainTextEdit, QPushButton, QProgressBar, QComboBox, QLabel, QCheckBox,
+                             QLineEdit, QMessageBox, QWidget, QToolTip)
+from PyQt5.QtCore import pyqtSlot, QThread, QSize, pyqtSignal
+from PyQt5.QtGui import QIcon, QTextCursor, QFont, QPixmap
+
 import concurrent.futures
 
 MYPATH = os.path.dirname(__file__)
@@ -29,14 +24,14 @@ try:
     from . import socketClient
     from . import dashboard_apps
     from .lib import LocalMachine
-    from .lib.file_extensions import check_all_extensions
+    from .lib.MicrosFiles import check_all_extensions
 except Exception as e:
     print("Import warning: {}".format(e))
     import MicrOSDevEnv
     import socketClient
     import dashboard_apps
     from lib import LocalMachine
-    from lib.file_extensions import check_all_extensions
+    from lib.MicrosFiles import check_all_extensions
 
 APP_DIR = os.path.join(MYPATH, 'dashboard_apps')
 
@@ -454,7 +449,7 @@ class HeaderInfo:
         logo_path = os.path.join(MYPATH, '../media/logo_mini.png')
         button = QPushButton('', self.parent_obj)
         button.setIcon(QIcon(logo_path))
-        button.setIconSize(QtCore.QSize(50, 50))
+        button.setIconSize(QSize(50, 50))
         button.setGeometry(20, 5, 50, 50)
         button.setToolTip(f"Open micrOS repo documentation\n{self.url}")
         button.setStyleSheet('border: 0px solid black;')
@@ -581,7 +576,7 @@ class ClusterStatus:
                     except:
                         hwuid = hello
             status = '🟢' if status else '🔴'
-            msg = f"{status}{hwuid}|{devip}🏷{fuid} v:️{version}"
+            msg = f"{status}{hwuid} | {devip}🏷{fuid} v:{version}"
             return msg
 
         with concurrent.futures.ThreadPoolExecutor() as executor:
@@ -954,7 +949,7 @@ class micrOSGUI(QWidget):
         self.devenv_usb_deployment_is_active = True
         # Create a Thread with a function without any arguments
         self.console.append_output('[usb_deploy] |- start usb_deploy job')
-        th = threading.Thread(target=self.devtool_obj.deploy_micros, kwargs={'restore': False, 'purge_conf': True},
+        th = threading.Thread(target=self.devtool_obj.deploy_micros, kwargs={'restore_config': False, "cleanup_workdir": True},
                               daemon=DAEMON)
         th.start()
         self.bgjob_thread_obj_dict['usb_deploy'] = th
@@ -1219,7 +1214,7 @@ class micrOSGUI(QWidget):
 
 def main():
     app = QApplication(sys.argv)
-    app.setWindowIcon(QtGui.QIcon(os.path.join(MYPATH, '../media/logo.png')))
+    app.setWindowIcon(QIcon(os.path.join(MYPATH, '../media/logo.png')))
     ex = micrOSGUI()
     ex.draw()
     sys.exit(app.exec_())
