@@ -1,4 +1,4 @@
-from sim_console import console
+from sim_common import console
 try:
     import resource
 except Exception as e:
@@ -25,8 +25,8 @@ def mem_info(*args, **kwargs):
     return total_heap, used_heap, free_heap
 
 
-def const(*args):
-    return args
+def const(arg):
+    return arg
 
 
 def schedule(callback, arg):
